@@ -161,7 +161,6 @@ class LodeStarData():
 
         """
         # Set the index as the date (preserver current)
-        self.data['_cur_idx'] = self.data.index.values
         self.data.set_index(date_col, inplace=True)
 
         # Resample
@@ -182,8 +181,9 @@ class LodeStarData():
         
         del _data['time']
 
+        _data.reset_index(drop=True, inplace=True)
+
         self.data = _data
-        self.data.set_index('_cur_idx', inplace=True)
 
 class _SlicedLodeStarData(LodeStarData):
     def __init__(self, lodestar_data, i_start, i_end, shift_time=True):        
