@@ -49,7 +49,7 @@ class Test_LodeStarDataResample(unittest.TestCase):
 
     def test_resampled_time(self):
         expected_times = [0, 0.021, 0.042]
-        self.assertListEqual(self.resampled_lodestar.data.index.values[:3], expected_times)
+        self.assertListEqual(list(self.resampled_lodestar.data.index.values[:3]), expected_times)
     
     def test_resampled_rpm(self):
 
@@ -59,7 +59,7 @@ class Test_LodeStarDataResample(unittest.TestCase):
         rpm_test = []
 
         for i in [3, 6]:
-            rpm_int.append(round(interp(self.resampled_lodestar.data.index.values[i], lodestar.data.index.values, lodestar.rpm), 4))
+            rpm_int.append(round(interp(self.resampled_lodestar.data.index.values[i], lodestar.data.index.values, lodestar.rpm), 3))
             rpm_test.append(round(self.resampled_lodestar.rpm[i], 3))
 
         self.assertListEqual(rpm_test, rpm_int)
